:py:mod:`piel.config`
=====================

.. py:module:: piel.config

.. autoapi-nested-parse::

   We create a set of parameters that can be used throughout the project for optimisation.

   The numerical solver is jax and is imported throughout the module.



Module Contents
---------------

.. py:data:: piel_path_types
